data = [
    {
        "id": "CWE_5",
        "code": "CWE-5",
        "url": "https://cwe.mitre.org/data/definitions/5.html",
    },
    {
        "id": "CWE_6",
        "code": "CWE-6",
        "url": "https://cwe.mitre.org/data/definitions/6.html",
    },
    {
        "id": "CWE_7",
        "code": "CWE-7",
        "url": "https://cwe.mitre.org/data/definitions/7.html",
    },
    {
        "id": "CWE_8",
        "code": "CWE-8",
        "url": "https://cwe.mitre.org/data/definitions/8.html",
    },
    {
        "id": "CWE_9",
        "code": "CWE-9",
        "url": "https://cwe.mitre.org/data/definitions/9.html",
    },
    {
        "id": "CWE_11",
        "code": "CWE-11",
        "url": "https://cwe.mitre.org/data/definitions/11.html",
    },
    {
        "id": "CWE_12",
        "code": "CWE-12",
        "url": "https://cwe.mitre.org/data/definitions/12.html",
    },
    {
        "id": "CWE_13",
        "code": "CWE-13",
        "url": "https://cwe.mitre.org/data/definitions/13.html",
    },
    {
        "id": "CWE_14",
        "code": "CWE-14",
        "url": "https://cwe.mitre.org/data/definitions/14.html",
    },
    {
        "id": "CWE_15",
        "code": "CWE-15",
        "url": "https://cwe.mitre.org/data/definitions/15.html",
    },
    {
        "id": "CWE_16",
        "code": "CWE-16",
        "url": "https://cwe.mitre.org/data/definitions/16.html",
    },
    {
        "id": "CWE_17",
        "code": "CWE-17",
        "url": "https://cwe.mitre.org/data/definitions/17.html",
    },
    {
        "id": "CWE_20",
        "code": "CWE-20",
        "url": "https://cwe.mitre.org/data/definitions/20.html",
    },
    {
        "id": "CWE_22",
        "code": "CWE-22",
        "url": "https://cwe.mitre.org/data/definitions/22.html",
    },
    {
        "id": "CWE_23",
        "code": "CWE-23",
        "url": "https://cwe.mitre.org/data/definitions/23.html",
    },
    {
        "id": "CWE_24",
        "code": "CWE-24",
        "url": "https://cwe.mitre.org/data/definitions/24.html",
    },
    {
        "id": "CWE_25",
        "code": "CWE-25",
        "url": "https://cwe.mitre.org/data/definitions/25.html",
    },
    {
        "id": "CWE_26",
        "code": "CWE-26",
        "url": "https://cwe.mitre.org/data/definitions/26.html",
    },
    {
        "id": "CWE_27",
        "code": "CWE-27",
        "url": "https://cwe.mitre.org/data/definitions/27.html",
    },
    {
        "id": "CWE_28",
        "code": "CWE-28",
        "url": "https://cwe.mitre.org/data/definitions/28.html",
    },
    {
        "id": "CWE_29",
        "code": "CWE-29",
        "url": "https://cwe.mitre.org/data/definitions/29.html",
    },
    {
        "id": "CWE_30",
        "code": "CWE-30",
        "url": "https://cwe.mitre.org/data/definitions/30.html",
    },
    {
        "id": "CWE_31",
        "code": "CWE-31",
        "url": "https://cwe.mitre.org/data/definitions/31.html",
    },
    {
        "id": "CWE_32",
        "code": "CWE-32",
        "url": "https://cwe.mitre.org/data/definitions/32.html",
    },
    {
        "id": "CWE_33",
        "code": "CWE-33",
        "url": "https://cwe.mitre.org/data/definitions/33.html",
    },
    {
        "id": "CWE_34",
        "code": "CWE-34",
        "url": "https://cwe.mitre.org/data/definitions/34.html",
    },
    {
        "id": "CWE_35",
        "code": "CWE-35",
        "url": "https://cwe.mitre.org/data/definitions/35.html",
    },
    {
        "id": "CWE_36",
        "code": "CWE-36",
        "url": "https://cwe.mitre.org/data/definitions/36.html",
    },
    {
        "id": "CWE_37",
        "code": "CWE-37",
        "url": "https://cwe.mitre.org/data/definitions/37.html",
    },
    {
        "id": "CWE_38",
        "code": "CWE-38",
        "url": "https://cwe.mitre.org/data/definitions/38.html",
    },
    {
        "id": "CWE_39",
        "code": "CWE-39",
        "url": "https://cwe.mitre.org/data/definitions/39.html",
    },
    {
        "id": "CWE_40",
        "code": "CWE-40",
        "url": "https://cwe.mitre.org/data/definitions/40.html",
    },
    {
        "id": "CWE_41",
        "code": "CWE-41",
        "url": "https://cwe.mitre.org/data/definitions/41.html",
    },
    {
        "id": "CWE_42",
        "code": "CWE-42",
        "url": "https://cwe.mitre.org/data/definitions/42.html",
    },
    {
        "id": "CWE_43",
        "code": "CWE-43",
        "url": "https://cwe.mitre.org/data/definitions/43.html",
    },
    {
        "id": "CWE_44",
        "code": "CWE-44",
        "url": "https://cwe.mitre.org/data/definitions/44.html",
    },
    {
        "id": "CWE_45",
        "code": "CWE-45",
        "url": "https://cwe.mitre.org/data/definitions/45.html",
    },
    {
        "id": "CWE_46",
        "code": "CWE-46",
        "url": "https://cwe.mitre.org/data/definitions/46.html",
    },
    {
        "id": "CWE_47",
        "code": "CWE-47",
        "url": "https://cwe.mitre.org/data/definitions/47.html",
    },
    {
        "id": "CWE_48",
        "code": "CWE-48",
        "url": "https://cwe.mitre.org/data/definitions/48.html",
    },
    {
        "id": "CWE_49",
        "code": "CWE-49",
        "url": "https://cwe.mitre.org/data/definitions/49.html",
    },
    {
        "id": "CWE_50",
        "code": "CWE-50",
        "url": "https://cwe.mitre.org/data/definitions/50.html",
    },
    {
        "id": "CWE_51",
        "code": "CWE-51",
        "url": "https://cwe.mitre.org/data/definitions/51.html",
    },
    {
        "id": "CWE_52",
        "code": "CWE-52",
        "url": "https://cwe.mitre.org/data/definitions/52.html",
    },
    {
        "id": "CWE_53",
        "code": "CWE-53",
        "url": "https://cwe.mitre.org/data/definitions/53.html",
    },
    {
        "id": "CWE_54",
        "code": "CWE-54",
        "url": "https://cwe.mitre.org/data/definitions/54.html",
    },
    {
        "id": "CWE_55",
        "code": "CWE-55",
        "url": "https://cwe.mitre.org/data/definitions/55.html",
    },
    {
        "id": "CWE_56",
        "code": "CWE-56",
        "url": "https://cwe.mitre.org/data/definitions/56.html",
    },
    {
        "id": "CWE_57",
        "code": "CWE-57",
        "url": "https://cwe.mitre.org/data/definitions/57.html",
    },
    {
        "id": "CWE_58",
        "code": "CWE-58",
        "url": "https://cwe.mitre.org/data/definitions/58.html",
    },
    {
        "id": "CWE_59",
        "code": "CWE-59",
        "url": "https://cwe.mitre.org/data/definitions/59.html",
    },
    {
        "id": "CWE_62",
        "code": "CWE-62",
        "url": "https://cwe.mitre.org/data/definitions/62.html",
    },
    {
        "id": "CWE_64",
        "code": "CWE-64",
        "url": "https://cwe.mitre.org/data/definitions/64.html",
    },
    {
        "id": "CWE_65",
        "code": "CWE-65",
        "url": "https://cwe.mitre.org/data/definitions/65.html",
    },
    {
        "id": "CWE_66",
        "code": "CWE-66",
        "url": "https://cwe.mitre.org/data/definitions/66.html",
    },
    {
        "id": "CWE_67",
        "code": "CWE-67",
        "url": "https://cwe.mitre.org/data/definitions/67.html",
    },
    {
        "id": "CWE_69",
        "code": "CWE-69",
        "url": "https://cwe.mitre.org/data/definitions/69.html",
    },
    {
        "id": "CWE_71",
        "code": "CWE-71",
        "url": "https://cwe.mitre.org/data/definitions/71.html",
    },
    {
        "id": "CWE_72",
        "code": "CWE-72",
        "url": "https://cwe.mitre.org/data/definitions/72.html",
    },
    {
        "id": "CWE_73",
        "code": "CWE-73",
        "url": "https://cwe.mitre.org/data/definitions/73.html",
    },
    {
        "id": "CWE_74",
        "code": "CWE-74",
        "url": "https://cwe.mitre.org/data/definitions/74.html",
    },
    {
        "id": "CWE_75",
        "code": "CWE-75",
        "url": "https://cwe.mitre.org/data/definitions/75.html",
    },
    {
        "id": "CWE_76",
        "code": "CWE-76",
        "url": "https://cwe.mitre.org/data/definitions/76.html",
    },
    {
        "id": "CWE_77",
        "code": "CWE-77",
        "url": "https://cwe.mitre.org/data/definitions/77.html",
    },
    {
        "id": "CWE_78",
        "code": "CWE-78",
        "url": "https://cwe.mitre.org/data/definitions/78.html",
    },
    {
        "id": "CWE_79",
        "code": "CWE-79",
        "url": "https://cwe.mitre.org/data/definitions/79.html",
    },
    {
        "id": "CWE_80",
        "code": "CWE-80",
        "url": "https://cwe.mitre.org/data/definitions/80.html",
    },
    {
        "id": "CWE_81",
        "code": "CWE-81",
        "url": "https://cwe.mitre.org/data/definitions/81.html",
    },
    {
        "id": "CWE_82",
        "code": "CWE-82",
        "url": "https://cwe.mitre.org/data/definitions/82.html",
    },
    {
        "id": "CWE_83",
        "code": "CWE-83",
        "url": "https://cwe.mitre.org/data/definitions/83.html",
    },
    {
        "id": "CWE_84",
        "code": "CWE-84",
        "url": "https://cwe.mitre.org/data/definitions/84.html",
    },
    {
        "id": "CWE_85",
        "code": "CWE-85",
        "url": "https://cwe.mitre.org/data/definitions/85.html",
    },
    {
        "id": "CWE_86",
        "code": "CWE-86",
        "url": "https://cwe.mitre.org/data/definitions/86.html",
    },
    {
        "id": "CWE_87",
        "code": "CWE-87",
        "url": "https://cwe.mitre.org/data/definitions/87.html",
    },
    {
        "id": "CWE_88",
        "code": "CWE-88",
        "url": "https://cwe.mitre.org/data/definitions/88.html",
    },
    {
        "id": "CWE_89",
        "code": "CWE-89",
        "url": "https://cwe.mitre.org/data/definitions/89.html",
    },
    {
        "id": "CWE_90",
        "code": "CWE-90",
        "url": "https://cwe.mitre.org/data/definitions/90.html",
    },
    {
        "id": "CWE_91",
        "code": "CWE-91",
        "url": "https://cwe.mitre.org/data/definitions/91.html",
    },
    {
        "id": "CWE_92",
        "code": "CWE-92",
        "url": "https://cwe.mitre.org/data/definitions/92.html",
    },
    {
        "id": "CWE_93",
        "code": "CWE-93",
        "url": "https://cwe.mitre.org/data/definitions/93.html",
    },
    {
        "id": "CWE_94",
        "code": "CWE-94",
        "url": "https://cwe.mitre.org/data/definitions/94.html",
    },
    {
        "id": "CWE_95",
        "code": "CWE-95",
        "url": "https://cwe.mitre.org/data/definitions/95.html",
    },
    {
        "id": "CWE_96",
        "code": "CWE-96",
        "url": "https://cwe.mitre.org/data/definitions/96.html",
    },
    {
        "id": "CWE_97",
        "code": "CWE-97",
        "url": "https://cwe.mitre.org/data/definitions/97.html",
    },
    {
        "id": "CWE_98",
        "code": "CWE-98",
        "url": "https://cwe.mitre.org/data/definitions/98.html",
    },
    {
        "id": "CWE_99",
        "code": "CWE-99",
        "url": "https://cwe.mitre.org/data/definitions/99.html",
    },
    {
        "id": "CWE_102",
        "code": "CWE-102",
        "url": "https://cwe.mitre.org/data/definitions/102.html",
    },
    {
        "id": "CWE_103",
        "code": "CWE-103",
        "url": "https://cwe.mitre.org/data/definitions/103.html",
    },
    {
        "id": "CWE_104",
        "code": "CWE-104",
        "url": "https://cwe.mitre.org/data/definitions/104.html",
    },
    {
        "id": "CWE_105",
        "code": "CWE-105",
        "url": "https://cwe.mitre.org/data/definitions/105.html",
    },
    {
        "id": "CWE_106",
        "code": "CWE-106",
        "url": "https://cwe.mitre.org/data/definitions/106.html",
    },
    {
        "id": "CWE_107",
        "code": "CWE-107",
        "url": "https://cwe.mitre.org/data/definitions/107.html",
    },
    {
        "id": "CWE_108",
        "code": "CWE-108",
        "url": "https://cwe.mitre.org/data/definitions/108.html",
    },
    {
        "id": "CWE_109",
        "code": "CWE-109",
        "url": "https://cwe.mitre.org/data/definitions/109.html",
    },
    {
        "id": "CWE_110",
        "code": "CWE-110",
        "url": "https://cwe.mitre.org/data/definitions/110.html",
    },
    {
        "id": "CWE_111",
        "code": "CWE-111",
        "url": "https://cwe.mitre.org/data/definitions/111.html",
    },
    {
        "id": "CWE_112",
        "code": "CWE-112",
        "url": "https://cwe.mitre.org/data/definitions/112.html",
    },
    {
        "id": "CWE_113",
        "code": "CWE-113",
        "url": "https://cwe.mitre.org/data/definitions/113.html",
    },
    {
        "id": "CWE_114",
        "code": "CWE-114",
        "url": "https://cwe.mitre.org/data/definitions/114.html",
    },
    {
        "id": "CWE_115",
        "code": "CWE-115",
        "url": "https://cwe.mitre.org/data/definitions/115.html",
    },
    {
        "id": "CWE_116",
        "code": "CWE-116",
        "url": "https://cwe.mitre.org/data/definitions/116.html",
    },
    {
        "id": "CWE_117",
        "code": "CWE-117",
        "url": "https://cwe.mitre.org/data/definitions/117.html",
    },
    {
        "id": "CWE_118",
        "code": "CWE-118",
        "url": "https://cwe.mitre.org/data/definitions/118.html",
    },
    {
        "id": "CWE_119",
        "code": "CWE-119",
        "url": "https://cwe.mitre.org/data/definitions/119.html",
    },
    {
        "id": "CWE_120",
        "code": "CWE-120",
        "url": "https://cwe.mitre.org/data/definitions/120.html",
    },
    {
        "id": "CWE_121",
        "code": "CWE-121",
        "url": "https://cwe.mitre.org/data/definitions/121.html",
    },
    {
        "id": "CWE_122",
        "code": "CWE-122",
        "url": "https://cwe.mitre.org/data/definitions/122.html",
    },
    {
        "id": "CWE_123",
        "code": "CWE-123",
        "url": "https://cwe.mitre.org/data/definitions/123.html",
    },
    {
        "id": "CWE_124",
        "code": "CWE-124",
        "url": "https://cwe.mitre.org/data/definitions/124.html",
    },
    {
        "id": "CWE_125",
        "code": "CWE-125",
        "url": "https://cwe.mitre.org/data/definitions/125.html",
    },
    {
        "id": "CWE_126",
        "code": "CWE-126",
        "url": "https://cwe.mitre.org/data/definitions/126.html",
    },
    {
        "id": "CWE_127",
        "code": "CWE-127",
        "url": "https://cwe.mitre.org/data/definitions/127.html",
    },
    {
        "id": "CWE_128",
        "code": "CWE-128",
        "url": "https://cwe.mitre.org/data/definitions/128.html",
    },
    {
        "id": "CWE_129",
        "code": "CWE-129",
        "url": "https://cwe.mitre.org/data/definitions/129.html",
    },
    {
        "id": "CWE_130",
        "code": "CWE-130",
        "url": "https://cwe.mitre.org/data/definitions/130.html",
    },
    {
        "id": "CWE_131",
        "code": "CWE-131",
        "url": "https://cwe.mitre.org/data/definitions/131.html",
    },
    {
        "id": "CWE_132",
        "code": "CWE-132",
        "url": "https://cwe.mitre.org/data/definitions/132.html",
    },
    {
        "id": "CWE_134",
        "code": "CWE-134",
        "url": "https://cwe.mitre.org/data/definitions/134.html",
    },
    {
        "id": "CWE_135",
        "code": "CWE-135",
        "url": "https://cwe.mitre.org/data/definitions/135.html",
    },
    {
        "id": "CWE_138",
        "code": "CWE-138",
        "url": "https://cwe.mitre.org/data/definitions/138.html",
    },
    {
        "id": "CWE_140",
        "code": "CWE-140",
        "url": "https://cwe.mitre.org/data/definitions/140.html",
    },
    {
        "id": "CWE_141",
        "code": "CWE-141",
        "url": "https://cwe.mitre.org/data/definitions/141.html",
    },
    {
        "id": "CWE_142",
        "code": "CWE-142",
        "url": "https://cwe.mitre.org/data/definitions/142.html",
    },
    {
        "id": "CWE_143",
        "code": "CWE-143",
        "url": "https://cwe.mitre.org/data/definitions/143.html",
    },
    {
        "id": "CWE_144",
        "code": "CWE-144",
        "url": "https://cwe.mitre.org/data/definitions/144.html",
    },
    {
        "id": "CWE_145",
        "code": "CWE-145",
        "url": "https://cwe.mitre.org/data/definitions/145.html",
    },
    {
        "id": "CWE_146",
        "code": "CWE-146",
        "url": "https://cwe.mitre.org/data/definitions/146.html",
    },
    {
        "id": "CWE_147",
        "code": "CWE-147",
        "url": "https://cwe.mitre.org/data/definitions/147.html",
    },
    {
        "id": "CWE_148",
        "code": "CWE-148",
        "url": "https://cwe.mitre.org/data/definitions/148.html",
    },
    {
        "id": "CWE_149",
        "code": "CWE-149",
        "url": "https://cwe.mitre.org/data/definitions/149.html",
    },
    {
        "id": "CWE_150",
        "code": "CWE-150",
        "url": "https://cwe.mitre.org/data/definitions/150.html",
    },
    {
        "id": "CWE_151",
        "code": "CWE-151",
        "url": "https://cwe.mitre.org/data/definitions/151.html",
    },
    {
        "id": "CWE_152",
        "code": "CWE-152",
        "url": "https://cwe.mitre.org/data/definitions/152.html",
    },
    {
        "id": "CWE_153",
        "code": "CWE-153",
        "url": "https://cwe.mitre.org/data/definitions/153.html",
    },
    {
        "id": "CWE_154",
        "code": "CWE-154",
        "url": "https://cwe.mitre.org/data/definitions/154.html",
    },
    {
        "id": "CWE_155",
        "code": "CWE-155",
        "url": "https://cwe.mitre.org/data/definitions/155.html",
    },
    {
        "id": "CWE_156",
        "code": "CWE-156",
        "url": "https://cwe.mitre.org/data/definitions/156.html",
    },
    {
        "id": "CWE_157",
        "code": "CWE-157",
        "url": "https://cwe.mitre.org/data/definitions/157.html",
    },
    {
        "id": "CWE_158",
        "code": "CWE-158",
        "url": "https://cwe.mitre.org/data/definitions/158.html",
    },
    {
        "id": "CWE_159",
        "code": "CWE-159",
        "url": "https://cwe.mitre.org/data/definitions/159.html",
    },
    {
        "id": "CWE_160",
        "code": "CWE-160",
        "url": "https://cwe.mitre.org/data/definitions/160.html",
    },
    {
        "id": "CWE_161",
        "code": "CWE-161",
        "url": "https://cwe.mitre.org/data/definitions/161.html",
    },
    {
        "id": "CWE_162",
        "code": "CWE-162",
        "url": "https://cwe.mitre.org/data/definitions/162.html",
    },
    {
        "id": "CWE_163",
        "code": "CWE-163",
        "url": "https://cwe.mitre.org/data/definitions/163.html",
    },
    {
        "id": "CWE_164",
        "code": "CWE-164",
        "url": "https://cwe.mitre.org/data/definitions/164.html",
    },
    {
        "id": "CWE_165",
        "code": "CWE-165",
        "url": "https://cwe.mitre.org/data/definitions/165.html",
    },
    {
        "id": "CWE_166",
        "code": "CWE-166",
        "url": "https://cwe.mitre.org/data/definitions/166.html",
    },
    {
        "id": "CWE_167",
        "code": "CWE-167",
        "url": "https://cwe.mitre.org/data/definitions/167.html",
    },
    {
        "id": "CWE_168",
        "code": "CWE-168",
        "url": "https://cwe.mitre.org/data/definitions/168.html",
    },
    {
        "id": "CWE_170",
        "code": "CWE-170",
        "url": "https://cwe.mitre.org/data/definitions/170.html",
    },
    {
        "id": "CWE_172",
        "code": "CWE-172",
        "url": "https://cwe.mitre.org/data/definitions/172.html",
    },
    {
        "id": "CWE_173",
        "code": "CWE-173",
        "url": "https://cwe.mitre.org/data/definitions/173.html",
    },
    {
        "id": "CWE_174",
        "code": "CWE-174",
        "url": "https://cwe.mitre.org/data/definitions/174.html",
    },
    {
        "id": "CWE_175",
        "code": "CWE-175",
        "url": "https://cwe.mitre.org/data/definitions/175.html",
    },
    {
        "id": "CWE_176",
        "code": "CWE-176",
        "url": "https://cwe.mitre.org/data/definitions/176.html",
    },
    {
        "id": "CWE_177",
        "code": "CWE-177",
        "url": "https://cwe.mitre.org/data/definitions/177.html",
    },
    {
        "id": "CWE_178",
        "code": "CWE-178",
        "url": "https://cwe.mitre.org/data/definitions/178.html",
    },
    {
        "id": "CWE_179",
        "code": "CWE-179",
        "url": "https://cwe.mitre.org/data/definitions/179.html",
    },
    {
        "id": "CWE_180",
        "code": "CWE-180",
        "url": "https://cwe.mitre.org/data/definitions/180.html",
    },
    {
        "id": "CWE_181",
        "code": "CWE-181",
        "url": "https://cwe.mitre.org/data/definitions/181.html",
    },
    {
        "id": "CWE_182",
        "code": "CWE-182",
        "url": "https://cwe.mitre.org/data/definitions/182.html",
    },
    {
        "id": "CWE_183",
        "code": "CWE-183",
        "url": "https://cwe.mitre.org/data/definitions/183.html",
    },
    {
        "id": "CWE_184",
        "code": "CWE-184",
        "url": "https://cwe.mitre.org/data/definitions/184.html",
    },
    {
        "id": "CWE_185",
        "code": "CWE-185",
        "url": "https://cwe.mitre.org/data/definitions/185.html",
    },
    {
        "id": "CWE_186",
        "code": "CWE-186",
        "url": "https://cwe.mitre.org/data/definitions/186.html",
    },
    {
        "id": "CWE_187",
        "code": "CWE-187",
        "url": "https://cwe.mitre.org/data/definitions/187.html",
    },
    {
        "id": "CWE_188",
        "code": "CWE-188",
        "url": "https://cwe.mitre.org/data/definitions/188.html",
    },
    {
        "id": "CWE_190",
        "code": "CWE-190",
        "url": "https://cwe.mitre.org/data/definitions/190.html",
    },
    {
        "id": "CWE_191",
        "code": "CWE-191",
        "url": "https://cwe.mitre.org/data/definitions/191.html",
    },
    {
        "id": "CWE_193",
        "code": "CWE-193",
        "url": "https://cwe.mitre.org/data/definitions/193.html",
    },
    {
        "id": "CWE_194",
        "code": "CWE-194",
        "url": "https://cwe.mitre.org/data/definitions/194.html",
    },
    {
        "id": "CWE_195",
        "code": "CWE-195",
        "url": "https://cwe.mitre.org/data/definitions/195.html",
    },
    {
        "id": "CWE_196",
        "code": "CWE-196",
        "url": "https://cwe.mitre.org/data/definitions/196.html",
    },
    {
        "id": "CWE_197",
        "code": "CWE-197",
        "url": "https://cwe.mitre.org/data/definitions/197.html",
    },
    {
        "id": "CWE_198",
        "code": "CWE-198",
        "url": "https://cwe.mitre.org/data/definitions/198.html",
    },
    {
        "id": "CWE_200",
        "code": "CWE-200",
        "url": "https://cwe.mitre.org/data/definitions/200.html",
    },
    {
        "id": "CWE_201",
        "code": "CWE-201",
        "url": "https://cwe.mitre.org/data/definitions/201.html",
    },
    {
        "id": "CWE_202",
        "code": "CWE-202",
        "url": "https://cwe.mitre.org/data/definitions/202.html",
    },
    {
        "id": "CWE_203",
        "code": "CWE-203",
        "url": "https://cwe.mitre.org/data/definitions/203.html",
    },
    {
        "id": "CWE_204",
        "code": "CWE-204",
        "url": "https://cwe.mitre.org/data/definitions/204.html",
    },
    {
        "id": "CWE_205",
        "code": "CWE-205",
        "url": "https://cwe.mitre.org/data/definitions/205.html",
    },
    {
        "id": "CWE_206",
        "code": "CWE-206",
        "url": "https://cwe.mitre.org/data/definitions/206.html",
    },
    {
        "id": "CWE_207",
        "code": "CWE-207",
        "url": "https://cwe.mitre.org/data/definitions/207.html",
    },
    {
        "id": "CWE_208",
        "code": "CWE-208",
        "url": "https://cwe.mitre.org/data/definitions/208.html",
    },
    {
        "id": "CWE_209",
        "code": "CWE-209",
        "url": "https://cwe.mitre.org/data/definitions/209.html",
    },
    {
        "id": "CWE_210",
        "code": "CWE-210",
        "url": "https://cwe.mitre.org/data/definitions/210.html",
    },
    {
        "id": "CWE_211",
        "code": "CWE-211",
        "url": "https://cwe.mitre.org/data/definitions/211.html",
    },
    {
        "id": "CWE_212",
        "code": "CWE-212",
        "url": "https://cwe.mitre.org/data/definitions/212.html",
    },
    {
        "id": "CWE_213",
        "code": "CWE-213",
        "url": "https://cwe.mitre.org/data/definitions/213.html",
    },
    {
        "id": "CWE_214",
        "code": "CWE-214",
        "url": "https://cwe.mitre.org/data/definitions/214.html",
    },
    {
        "id": "CWE_215",
        "code": "CWE-215",
        "url": "https://cwe.mitre.org/data/definitions/215.html",
    },
    {
        "id": "CWE_216",
        "code": "CWE-216",
        "url": "https://cwe.mitre.org/data/definitions/216.html",
    },
    {
        "id": "CWE_217",
        "code": "CWE-217",
        "url": "https://cwe.mitre.org/data/definitions/217.html",
    },
    {
        "id": "CWE_218",
        "code": "CWE-218",
        "url": "https://cwe.mitre.org/data/definitions/218.html",
    },
    {
        "id": "CWE_219",
        "code": "CWE-219",
        "url": "https://cwe.mitre.org/data/definitions/219.html",
    },
    {
        "id": "CWE_220",
        "code": "CWE-220",
        "url": "https://cwe.mitre.org/data/definitions/220.html",
    },
    {
        "id": "CWE_221",
        "code": "CWE-221",
        "url": "https://cwe.mitre.org/data/definitions/221.html",
    },
    {
        "id": "CWE_222",
        "code": "CWE-222",
        "url": "https://cwe.mitre.org/data/definitions/222.html",
    },
    {
        "id": "CWE_223",
        "code": "CWE-223",
        "url": "https://cwe.mitre.org/data/definitions/223.html",
    },
    {
        "id": "CWE_224",
        "code": "CWE-224",
        "url": "https://cwe.mitre.org/data/definitions/224.html",
    },
    {
        "id": "CWE_225",
        "code": "CWE-225",
        "url": "https://cwe.mitre.org/data/definitions/225.html",
    },
    {
        "id": "CWE_226",
        "code": "CWE-226",
        "url": "https://cwe.mitre.org/data/definitions/226.html",
    },
    {
        "id": "CWE_227",
        "code": "CWE-227",
        "url": "https://cwe.mitre.org/data/definitions/227.html",
    },
    {
        "id": "CWE_228",
        "code": "CWE-228",
        "url": "https://cwe.mitre.org/data/definitions/228.html",
    },
    {
        "id": "CWE_229",
        "code": "CWE-229",
        "url": "https://cwe.mitre.org/data/definitions/229.html",
    },
    {
        "id": "CWE_230",
        "code": "CWE-230",
        "url": "https://cwe.mitre.org/data/definitions/230.html",
    },
    {
        "id": "CWE_231",
        "code": "CWE-231",
        "url": "https://cwe.mitre.org/data/definitions/231.html",
    },
    {
        "id": "CWE_232",
        "code": "CWE-232",
        "url": "https://cwe.mitre.org/data/definitions/232.html",
    },
    {
        "id": "CWE_233",
        "code": "CWE-233",
        "url": "https://cwe.mitre.org/data/definitions/233.html",
    },
    {
        "id": "CWE_234",
        "code": "CWE-234",
        "url": "https://cwe.mitre.org/data/definitions/234.html",
    },
    {
        "id": "CWE_235",
        "code": "CWE-235",
        "url": "https://cwe.mitre.org/data/definitions/235.html",
    },
    {
        "id": "CWE_236",
        "code": "CWE-236",
        "url": "https://cwe.mitre.org/data/definitions/236.html",
    },
    {
        "id": "CWE_237",
        "code": "CWE-237",
        "url": "https://cwe.mitre.org/data/definitions/237.html",
    },
    {
        "id": "CWE_238",
        "code": "CWE-238",
        "url": "https://cwe.mitre.org/data/definitions/238.html",
    },
    {
        "id": "CWE_239",
        "code": "CWE-239",
        "url": "https://cwe.mitre.org/data/definitions/239.html",
    },
    {
        "id": "CWE_240",
        "code": "CWE-240",
        "url": "https://cwe.mitre.org/data/definitions/240.html",
    },
    {
        "id": "CWE_241",
        "code": "CWE-241",
        "url": "https://cwe.mitre.org/data/definitions/241.html",
    },
    {
        "id": "CWE_242",
        "code": "CWE-242",
        "url": "https://cwe.mitre.org/data/definitions/242.html",
    },
    {
        "id": "CWE_243",
        "code": "CWE-243",
        "url": "https://cwe.mitre.org/data/definitions/243.html",
    },
    {
        "id": "CWE_244",
        "code": "CWE-244",
        "url": "https://cwe.mitre.org/data/definitions/244.html",
    },
    {
        "id": "CWE_245",
        "code": "CWE-245",
        "url": "https://cwe.mitre.org/data/definitions/245.html",
    },
    {
        "id": "CWE_246",
        "code": "CWE-246",
        "url": "https://cwe.mitre.org/data/definitions/246.html",
    },
    {
        "id": "CWE_247",
        "code": "CWE-247",
        "url": "https://cwe.mitre.org/data/definitions/247.html",
    },
    {
        "id": "CWE_248",
        "code": "CWE-248",
        "url": "https://cwe.mitre.org/data/definitions/248.html",
    },
    {
        "id": "CWE_249",
        "code": "CWE-249",
        "url": "https://cwe.mitre.org/data/definitions/249.html",
    },
    {
        "id": "CWE_250",
        "code": "CWE-250",
        "url": "https://cwe.mitre.org/data/definitions/250.html",
    },
    {
        "id": "CWE_252",
        "code": "CWE-252",
        "url": "https://cwe.mitre.org/data/definitions/252.html",
    },
    {
        "id": "CWE_253",
        "code": "CWE-253",
        "url": "https://cwe.mitre.org/data/definitions/253.html",
    },
    {
        "id": "CWE_256",
        "code": "CWE-256",
        "url": "https://cwe.mitre.org/data/definitions/256.html",
    },
    {
        "id": "CWE_257",
        "code": "CWE-257",
        "url": "https://cwe.mitre.org/data/definitions/257.html",
    },
    {
        "id": "CWE_258",
        "code": "CWE-258",
        "url": "https://cwe.mitre.org/data/definitions/258.html",
    },
    {
        "id": "CWE_259",
        "code": "CWE-259",
        "url": "https://cwe.mitre.org/data/definitions/259.html",
    },
    {
        "id": "CWE_260",
        "code": "CWE-260",
        "url": "https://cwe.mitre.org/data/definitions/260.html",
    },
    {
        "id": "CWE_261",
        "code": "CWE-261",
        "url": "https://cwe.mitre.org/data/definitions/261.html",
    },
    {
        "id": "CWE_262",
        "code": "CWE-262",
        "url": "https://cwe.mitre.org/data/definitions/262.html",
    },
    {
        "id": "CWE_263",
        "code": "CWE-263",
        "url": "https://cwe.mitre.org/data/definitions/263.html",
    },
    {
        "id": "CWE_266",
        "code": "CWE-266",
        "url": "https://cwe.mitre.org/data/definitions/266.html",
    },
    {
        "id": "CWE_267",
        "code": "CWE-267",
        "url": "https://cwe.mitre.org/data/definitions/267.html",
    },
    {
        "id": "CWE_268",
        "code": "CWE-268",
        "url": "https://cwe.mitre.org/data/definitions/268.html",
    },
    {
        "id": "CWE_269",
        "code": "CWE-269",
        "url": "https://cwe.mitre.org/data/definitions/269.html",
    },
    {
        "id": "CWE_270",
        "code": "CWE-270",
        "url": "https://cwe.mitre.org/data/definitions/270.html",
    },
    {
        "id": "CWE_271",
        "code": "CWE-271",
        "url": "https://cwe.mitre.org/data/definitions/271.html",
    },
    {
        "id": "CWE_272",
        "code": "CWE-272",
        "url": "https://cwe.mitre.org/data/definitions/272.html",
    },
    {
        "id": "CWE_273",
        "code": "CWE-273",
        "url": "https://cwe.mitre.org/data/definitions/273.html",
    },
    {
        "id": "CWE_274",
        "code": "CWE-274",
        "url": "https://cwe.mitre.org/data/definitions/274.html",
    },
    {
        "id": "CWE_276",
        "code": "CWE-276",
        "url": "https://cwe.mitre.org/data/definitions/276.html",
    },
    {
        "id": "CWE_277",
        "code": "CWE-277",
        "url": "https://cwe.mitre.org/data/definitions/277.html",
    },
    {
        "id": "CWE_278",
        "code": "CWE-278",
        "url": "https://cwe.mitre.org/data/definitions/278.html",
    },
    {
        "id": "CWE_279",
        "code": "CWE-279",
        "url": "https://cwe.mitre.org/data/definitions/279.html",
    },
    {
        "id": "CWE_280",
        "code": "CWE-280",
        "url": "https://cwe.mitre.org/data/definitions/280.html",
    },
    {
        "id": "CWE_281",
        "code": "CWE-281",
        "url": "https://cwe.mitre.org/data/definitions/281.html",
    },
    {
        "id": "CWE_282",
        "code": "CWE-282",
        "url": "https://cwe.mitre.org/data/definitions/282.html",
    },
    {
        "id": "CWE_283",
        "code": "CWE-283",
        "url": "https://cwe.mitre.org/data/definitions/283.html",
    },
    {
        "id": "CWE_284",
        "code": "CWE-284",
        "url": "https://cwe.mitre.org/data/definitions/284.html",
    },
    {
        "id": "CWE_285",
        "code": "CWE-285",
        "url": "https://cwe.mitre.org/data/definitions/285.html",
    },
    {
        "id": "CWE_286",
        "code": "CWE-286",
        "url": "https://cwe.mitre.org/data/definitions/286.html",
    },
    {
        "id": "CWE_287",
        "code": "CWE-287",
        "url": "https://cwe.mitre.org/data/definitions/287.html",
    },
    {
        "id": "CWE_288",
        "code": "CWE-288",
        "url": "https://cwe.mitre.org/data/definitions/288.html",
    },
    {
        "id": "CWE_289",
        "code": "CWE-289",
        "url": "https://cwe.mitre.org/data/definitions/289.html",
    },
    {
        "id": "CWE_290",
        "code": "CWE-290",
        "url": "https://cwe.mitre.org/data/definitions/290.html",
    },
    {
        "id": "CWE_292",
        "code": "CWE-292",
        "url": "https://cwe.mitre.org/data/definitions/292.html",
    },
    {
        "id": "CWE_293",
        "code": "CWE-293",
        "url": "https://cwe.mitre.org/data/definitions/293.html",
    },
    {
        "id": "CWE_294",
        "code": "CWE-294",
        "url": "https://cwe.mitre.org/data/definitions/294.html",
    },
    {
        "id": "CWE_295",
        "code": "CWE-295",
        "url": "https://cwe.mitre.org/data/definitions/295.html",
    },
    {
        "id": "CWE_296",
        "code": "CWE-296",
        "url": "https://cwe.mitre.org/data/definitions/296.html",
    },
    {
        "id": "CWE_297",
        "code": "CWE-297",
        "url": "https://cwe.mitre.org/data/definitions/297.html",
    },
    {
        "id": "CWE_298",
        "code": "CWE-298",
        "url": "https://cwe.mitre.org/data/definitions/298.html",
    },
    {
        "id": "CWE_299",
        "code": "CWE-299",
        "url": "https://cwe.mitre.org/data/definitions/299.html",
    },
    {
        "id": "CWE_300",
        "code": "CWE-300",
        "url": "https://cwe.mitre.org/data/definitions/300.html",
    },
    {
        "id": "CWE_301",
        "code": "CWE-301",
        "url": "https://cwe.mitre.org/data/definitions/301.html",
    },
    {
        "id": "CWE_302",
        "code": "CWE-302",
        "url": "https://cwe.mitre.org/data/definitions/302.html",
    },
    {
        "id": "CWE_303",
        "code": "CWE-303",
        "url": "https://cwe.mitre.org/data/definitions/303.html",
    },
    {
        "id": "CWE_304",
        "code": "CWE-304",
        "url": "https://cwe.mitre.org/data/definitions/304.html",
    },
    {
        "id": "CWE_305",
        "code": "CWE-305",
        "url": "https://cwe.mitre.org/data/definitions/305.html",
    },
    {
        "id": "CWE_306",
        "code": "CWE-306",
        "url": "https://cwe.mitre.org/data/definitions/306.html",
    },
    {
        "id": "CWE_307",
        "code": "CWE-307",
        "url": "https://cwe.mitre.org/data/definitions/307.html",
    },
    {
        "id": "CWE_308",
        "code": "CWE-308",
        "url": "https://cwe.mitre.org/data/definitions/308.html",
    },
    {
        "id": "CWE_309",
        "code": "CWE-309",
        "url": "https://cwe.mitre.org/data/definitions/309.html",
    },
    {
        "id": "CWE_310",
        "code": "CWE-310",
        "url": "https://cwe.mitre.org/data/definitions/310.html",
    },
    {
        "id": "CWE_311",
        "code": "CWE-311",
        "url": "https://cwe.mitre.org/data/definitions/311.html",
    },
    {
        "id": "CWE_312",
        "code": "CWE-312",
        "url": "https://cwe.mitre.org/data/definitions/312.html",
    },
    {
        "id": "CWE_313",
        "code": "CWE-313",
        "url": "https://cwe.mitre.org/data/definitions/313.html",
    },
    {
        "id": "CWE_314",
        "code": "CWE-314",
        "url": "https://cwe.mitre.org/data/definitions/314.html",
    },
    {
        "id": "CWE_315",
        "code": "CWE-315",
        "url": "https://cwe.mitre.org/data/definitions/315.html",
    },
    {
        "id": "CWE_316",
        "code": "CWE-316",
        "url": "https://cwe.mitre.org/data/definitions/316.html",
    },
    {
        "id": "CWE_317",
        "code": "CWE-317",
        "url": "https://cwe.mitre.org/data/definitions/317.html",
    },
    {
        "id": "CWE_318",
        "code": "CWE-318",
        "url": "https://cwe.mitre.org/data/definitions/318.html",
    },
    {
        "id": "CWE_319",
        "code": "CWE-319",
        "url": "https://cwe.mitre.org/data/definitions/319.html",
    },
    {
        "id": "CWE_321",
        "code": "CWE-321",
        "url": "https://cwe.mitre.org/data/definitions/321.html",
    },
    {
        "id": "CWE_322",
        "code": "CWE-322",
        "url": "https://cwe.mitre.org/data/definitions/322.html",
    },
    {
        "id": "CWE_323",
        "code": "CWE-323",
        "url": "https://cwe.mitre.org/data/definitions/323.html",
    },
    {
        "id": "CWE_324",
        "code": "CWE-324",
        "url": "https://cwe.mitre.org/data/definitions/324.html",
    },
    {
        "id": "CWE_325",
        "code": "CWE-325",
        "url": "https://cwe.mitre.org/data/definitions/325.html",
    },
    {
        "id": "CWE_326",
        "code": "CWE-326",
        "url": "https://cwe.mitre.org/data/definitions/326.html",
    },
    {
        "id": "CWE_327",
        "code": "CWE-327",
        "url": "https://cwe.mitre.org/data/definitions/327.html",
    },
    {
        "id": "CWE_328",
        "code": "CWE-328",
        "url": "https://cwe.mitre.org/data/definitions/328.html",
    },
    {
        "id": "CWE_329",
        "code": "CWE-329",
        "url": "https://cwe.mitre.org/data/definitions/329.html",
    },
    {
        "id": "CWE_330",
        "code": "CWE-330",
        "url": "https://cwe.mitre.org/data/definitions/330.html",
    },
    {
        "id": "CWE_331",
        "code": "CWE-331",
        "url": "https://cwe.mitre.org/data/definitions/331.html",
    },
    {
        "id": "CWE_332",
        "code": "CWE-332",
        "url": "https://cwe.mitre.org/data/definitions/332.html",
    },
    {
        "id": "CWE_333",
        "code": "CWE-333",
        "url": "https://cwe.mitre.org/data/definitions/333.html",
    },
    {
        "id": "CWE_334",
        "code": "CWE-334",
        "url": "https://cwe.mitre.org/data/definitions/334.html",
    },
    {
        "id": "CWE_335",
        "code": "CWE-335",
        "url": "https://cwe.mitre.org/data/definitions/335.html",
    },
    {
        "id": "CWE_336",
        "code": "CWE-336",
        "url": "https://cwe.mitre.org/data/definitions/336.html",
    },
    {
        "id": "CWE_337",
        "code": "CWE-337",
        "url": "https://cwe.mitre.org/data/definitions/337.html",
    },
    {
        "id": "CWE_338",
        "code": "CWE-338",
        "url": "https://cwe.mitre.org/data/definitions/338.html",
    },
    {
        "id": "CWE_339",
        "code": "CWE-339",
        "url": "https://cwe.mitre.org/data/definitions/339.html",
    },
    {
        "id": "CWE_340",
        "code": "CWE-340",
        "url": "https://cwe.mitre.org/data/definitions/340.html",
    },
    {
        "id": "CWE_341",
        "code": "CWE-341",
        "url": "https://cwe.mitre.org/data/definitions/341.html",
    },
    {
        "id": "CWE_342",
        "code": "CWE-342",
        "url": "https://cwe.mitre.org/data/definitions/342.html",
    },
    {
        "id": "CWE_343",
        "code": "CWE-343",
        "url": "https://cwe.mitre.org/data/definitions/343.html",
    },
    {
        "id": "CWE_344",
        "code": "CWE-344",
        "url": "https://cwe.mitre.org/data/definitions/344.html",
    },
    {
        "id": "CWE_345",
        "code": "CWE-345",
        "url": "https://cwe.mitre.org/data/definitions/345.html",
    },
    {
        "id": "CWE_346",
        "code": "CWE-346",
        "url": "https://cwe.mitre.org/data/definitions/346.html",
    },
    {
        "id": "CWE_347",
        "code": "CWE-347",
        "url": "https://cwe.mitre.org/data/definitions/347.html",
    },
    {
        "id": "CWE_348",
        "code": "CWE-348",
        "url": "https://cwe.mitre.org/data/definitions/348.html",
    },
    {
        "id": "CWE_349",
        "code": "CWE-349",
        "url": "https://cwe.mitre.org/data/definitions/349.html",
    },
    {
        "id": "CWE_350",
        "code": "CWE-350",
        "url": "https://cwe.mitre.org/data/definitions/350.html",
    },
    {
        "id": "CWE_351",
        "code": "CWE-351",
        "url": "https://cwe.mitre.org/data/definitions/351.html",
    },
    {
        "id": "CWE_353",
        "code": "CWE-353",
        "url": "https://cwe.mitre.org/data/definitions/353.html",
    },
    {
        "id": "CWE_354",
        "code": "CWE-354",
        "url": "https://cwe.mitre.org/data/definitions/354.html",
    },
    {
        "id": "CWE_356",
        "code": "CWE-356",
        "url": "https://cwe.mitre.org/data/definitions/356.html",
    },
    {
        "id": "CWE_357",
        "code": "CWE-357",
        "url": "https://cwe.mitre.org/data/definitions/357.html",
    },
    {
        "id": "CWE_358",
        "code": "CWE-358",
        "url": "https://cwe.mitre.org/data/definitions/358.html",
    },
    {
        "id": "CWE_359",
        "code": "CWE-359",
        "url": "https://cwe.mitre.org/data/definitions/359.html",
    },
    {
        "id": "CWE_360",
        "code": "CWE-360",
        "url": "https://cwe.mitre.org/data/definitions/360.html",
    },
    {
        "id": "CWE_362",
        "code": "CWE-362",
        "url": "https://cwe.mitre.org/data/definitions/362.html",
    },
    {
        "id": "CWE_363",
        "code": "CWE-363",
        "url": "https://cwe.mitre.org/data/definitions/363.html",
    },
    {
        "id": "CWE_364",
        "code": "CWE-364",
        "url": "https://cwe.mitre.org/data/definitions/364.html",
    },
    {
        "id": "CWE_365",
        "code": "CWE-365",
        "url": "https://cwe.mitre.org/data/definitions/365.html",
    },
    {
        "id": "CWE_366",
        "code": "CWE-366",
        "url": "https://cwe.mitre.org/data/definitions/366.html",
    },
    {
        "id": "CWE_367",
        "code": "CWE-367",
        "url": "https://cwe.mitre.org/data/definitions/367.html",
    },
    {
        "id": "CWE_368",
        "code": "CWE-368",
        "url": "https://cwe.mitre.org/data/definitions/368.html",
    },
    {
        "id": "CWE_369",
        "code": "CWE-369",
        "url": "https://cwe.mitre.org/data/definitions/369.html",
    },
    {
        "id": "CWE_370",
        "code": "CWE-370",
        "url": "https://cwe.mitre.org/data/definitions/370.html",
    },
    {
        "id": "CWE_372",
        "code": "CWE-372",
        "url": "https://cwe.mitre.org/data/definitions/372.html",
    },
    {
        "id": "CWE_373",
        "code": "CWE-373",
        "url": "https://cwe.mitre.org/data/definitions/373.html",
    },
    {
        "id": "CWE_374",
        "code": "CWE-374",
        "url": "https://cwe.mitre.org/data/definitions/374.html",
    },
    {
        "id": "CWE_375",
        "code": "CWE-375",
        "url": "https://cwe.mitre.org/data/definitions/375.html",
    },
    {
        "id": "CWE_377",
        "code": "CWE-377",
        "url": "https://cwe.mitre.org/data/definitions/377.html",
    },
    {
        "id": "CWE_378",
        "code": "CWE-378",
        "url": "https://cwe.mitre.org/data/definitions/378.html",
    },
    {
        "id": "CWE_379",
        "code": "CWE-379",
        "url": "https://cwe.mitre.org/data/definitions/379.html",
    },
    {
        "id": "CWE_382",
        "code": "CWE-382",
        "url": "https://cwe.mitre.org/data/definitions/382.html",
    },
    {
        "id": "CWE_383",
        "code": "CWE-383",
        "url": "https://cwe.mitre.org/data/definitions/383.html",
    },
    {
        "id": "CWE_385",
        "code": "CWE-385",
        "url": "https://cwe.mitre.org/data/definitions/385.html",
    },
    {
        "id": "CWE_386",
        "code": "CWE-386",
        "url": "https://cwe.mitre.org/data/definitions/386.html",
    },
    {
        "id": "CWE_390",
        "code": "CWE-390",
        "url": "https://cwe.mitre.org/data/definitions/390.html",
    },
    {
        "id": "CWE_391",
        "code": "CWE-391",
        "url": "https://cwe.mitre.org/data/definitions/391.html",
    },
    {
        "id": "CWE_392",
        "code": "CWE-392",
        "url": "https://cwe.mitre.org/data/definitions/392.html",
    },
    {
        "id": "CWE_393",
        "code": "CWE-393",
        "url": "https://cwe.mitre.org/data/definitions/393.html",
    },
    {
        "id": "CWE_394",
        "code": "CWE-394",
        "url": "https://cwe.mitre.org/data/definitions/394.html",
    },
    {
        "id": "CWE_395",
        "code": "CWE-395",
        "url": "https://cwe.mitre.org/data/definitions/395.html",
    },
    {
        "id": "CWE_396",
        "code": "CWE-396",
        "url": "https://cwe.mitre.org/data/definitions/396.html",
    },
    {
        "id": "CWE_397",
        "code": "CWE-397",
        "url": "https://cwe.mitre.org/data/definitions/397.html",
    },
    {
        "id": "CWE_398",
        "code": "CWE-398",
        "url": "https://cwe.mitre.org/data/definitions/398.html",
    },
    {
        "id": "CWE_400",
        "code": "CWE-400",
        "url": "https://cwe.mitre.org/data/definitions/400.html",
    },
    {
        "id": "CWE_401",
        "code": "CWE-401",
        "url": "https://cwe.mitre.org/data/definitions/401.html",
    },
    {
        "id": "CWE_402",
        "code": "CWE-402",
        "url": "https://cwe.mitre.org/data/definitions/402.html",
    },
    {
        "id": "CWE_403",
        "code": "CWE-403",
        "url": "https://cwe.mitre.org/data/definitions/403.html",
    },
    {
        "id": "CWE_404",
        "code": "CWE-404",
        "url": "https://cwe.mitre.org/data/definitions/404.html",
    },
    {
        "id": "CWE_405",
        "code": "CWE-405",
        "url": "https://cwe.mitre.org/data/definitions/405.html",
    },
    {
        "id": "CWE_406",
        "code": "CWE-406",
        "url": "https://cwe.mitre.org/data/definitions/406.html",
    },
    {
        "id": "CWE_407",
        "code": "CWE-407",
        "url": "https://cwe.mitre.org/data/definitions/407.html",
    },
    {
        "id": "CWE_408",
        "code": "CWE-408",
        "url": "https://cwe.mitre.org/data/definitions/408.html",
    },
    {
        "id": "CWE_409",
        "code": "CWE-409",
        "url": "https://cwe.mitre.org/data/definitions/409.html",
    },
    {
        "id": "CWE_410",
        "code": "CWE-410",
        "url": "https://cwe.mitre.org/data/definitions/410.html",
    },
    {
        "id": "CWE_412",
        "code": "CWE-412",
        "url": "https://cwe.mitre.org/data/definitions/412.html",
    },
    {
        "id": "CWE_413",
        "code": "CWE-413",
        "url": "https://cwe.mitre.org/data/definitions/413.html",
    },
    {
        "id": "CWE_414",
        "code": "CWE-414",
        "url": "https://cwe.mitre.org/data/definitions/414.html",
    },
    {
        "id": "CWE_415",
        "code": "CWE-415",
        "url": "https://cwe.mitre.org/data/definitions/415.html",
    },
    {
        "id": "CWE_416",
        "code": "CWE-416",
        "url": "https://cwe.mitre.org/data/definitions/416.html",
    },
    {
        "id": "CWE_419",
        "code": "CWE-419",
        "url": "https://cwe.mitre.org/data/definitions/419.html",
    },
    {
        "id": "CWE_420",
        "code": "CWE-420",
        "url": "https://cwe.mitre.org/data/definitions/420.html",
    },
    {
        "id": "CWE_421",
        "code": "CWE-421",
        "url": "https://cwe.mitre.org/data/definitions/421.html",
    },
    {
        "id": "CWE_422",
        "code": "CWE-422",
        "url": "https://cwe.mitre.org/data/definitions/422.html",
    },
    {
        "id": "CWE_423",
        "code": "CWE-423",
        "url": "https://cwe.mitre.org/data/definitions/423.html",
    },
    {
        "id": "CWE_424",
        "code": "CWE-424",
        "url": "https://cwe.mitre.org/data/definitions/424.html",
    },
    {
        "id": "CWE_425",
        "code": "CWE-425",
        "url": "https://cwe.mitre.org/data/definitions/425.html",
    },
    {
        "id": "CWE_427",
        "code": "CWE-427",
        "url": "https://cwe.mitre.org/data/definitions/427.html",
    },
    {
        "id": "CWE_428",
        "code": "CWE-428",
        "url": "https://cwe.mitre.org/data/definitions/428.html",
    },
    {
        "id": "CWE_430",
        "code": "CWE-430",
        "url": "https://cwe.mitre.org/data/definitions/430.html",
    },
    {
        "id": "CWE_431",
        "code": "CWE-431",
        "url": "https://cwe.mitre.org/data/definitions/431.html",
    },
    {
        "id": "CWE_432",
        "code": "CWE-432",
        "url": "https://cwe.mitre.org/data/definitions/432.html",
    },
    {
        "id": "CWE_433",
        "code": "CWE-433",
        "url": "https://cwe.mitre.org/data/definitions/433.html",
    },
    {
        "id": "CWE_434",
        "code": "CWE-434",
        "url": "https://cwe.mitre.org/data/definitions/434.html",
    },
    {
        "id": "CWE_435",
        "code": "CWE-435",
        "url": "https://cwe.mitre.org/data/definitions/435.html",
    },
    {
        "id": "CWE_436",
        "code": "CWE-436",
        "url": "https://cwe.mitre.org/data/definitions/436.html",
    },
    {
        "id": "CWE_437",
        "code": "CWE-437",
        "url": "https://cwe.mitre.org/data/definitions/437.html",
    },
    {
        "id": "CWE_439",
        "code": "CWE-439",
        "url": "https://cwe.mitre.org/data/definitions/439.html",
    },
    {
        "id": "CWE_440",
        "code": "CWE-440",
        "url": "https://cwe.mitre.org/data/definitions/440.html",
    },
    {
        "id": "CWE_441",
        "code": "CWE-441",
        "url": "https://cwe.mitre.org/data/definitions/441.html",
    },
    {
        "id": "CWE_443",
        "code": "CWE-443",
        "url": "https://cwe.mitre.org/data/definitions/443.html",
    },
    {
        "id": "CWE_444",
        "code": "CWE-444",
        "url": "https://cwe.mitre.org/data/definitions/444.html",
    },
    {
        "id": "CWE_446",
        "code": "CWE-446",
        "url": "https://cwe.mitre.org/data/definitions/446.html",
    },
    {
        "id": "CWE_447",
        "code": "CWE-447",
        "url": "https://cwe.mitre.org/data/definitions/447.html",
    },
    {
        "id": "CWE_448",
        "code": "CWE-448",
        "url": "https://cwe.mitre.org/data/definitions/448.html",
    },
    {
        "id": "CWE_449",
        "code": "CWE-449",
        "url": "https://cwe.mitre.org/data/definitions/449.html",
    },
    {
        "id": "CWE_450",
        "code": "CWE-450",
        "url": "https://cwe.mitre.org/data/definitions/450.html",
    },
    {
        "id": "CWE_451",
        "code": "CWE-451",
        "url": "https://cwe.mitre.org/data/definitions/451.html",
    },
    {
        "id": "CWE_453",
        "code": "CWE-453",
        "url": "https://cwe.mitre.org/data/definitions/453.html",
    },
    {
        "id": "CWE_454",
        "code": "CWE-454",
        "url": "https://cwe.mitre.org/data/definitions/454.html",
    },
    {
        "id": "CWE_455",
        "code": "CWE-455",
        "url": "https://cwe.mitre.org/data/definitions/455.html",
    },
    {
        "id": "CWE_456",
        "code": "CWE-456",
        "url": "https://cwe.mitre.org/data/definitions/456.html",
    },
    {
        "id": "CWE_457",
        "code": "CWE-457",
        "url": "https://cwe.mitre.org/data/definitions/457.html",
    },
    {
        "id": "CWE_458",
        "code": "CWE-458",
        "url": "https://cwe.mitre.org/data/definitions/458.html",
    },
    {
        "id": "CWE_459",
        "code": "CWE-459",
        "url": "https://cwe.mitre.org/data/definitions/459.html",
    },
    {
        "id": "CWE_460",
        "code": "CWE-460",
        "url": "https://cwe.mitre.org/data/definitions/460.html",
    },
    {
        "id": "CWE_462",
        "code": "CWE-462",
        "url": "https://cwe.mitre.org/data/definitions/462.html",
    },
    {
        "id": "CWE_463",
        "code": "CWE-463",
        "url": "https://cwe.mitre.org/data/definitions/463.html",
    },
    {
        "id": "CWE_464",
        "code": "CWE-464",
        "url": "https://cwe.mitre.org/data/definitions/464.html",
    },
    {
        "id": "CWE_466",
        "code": "CWE-466",
        "url": "https://cwe.mitre.org/data/definitions/466.html",
    },
    {
        "id": "CWE_467",
        "code": "CWE-467",
        "url": "https://cwe.mitre.org/data/definitions/467.html",
    },
    {
        "id": "CWE_468",
        "code": "CWE-468",
        "url": "https://cwe.mitre.org/data/definitions/468.html",
    },
    {
        "id": "CWE_469",
        "code": "CWE-469",
        "url": "https://cwe.mitre.org/data/definitions/469.html",
    },
    {
        "id": "CWE_470",
        "code": "CWE-470",
        "url": "https://cwe.mitre.org/data/definitions/470.html",
    },
    {
        "id": "CWE_471",
        "code": "CWE-471",
        "url": "https://cwe.mitre.org/data/definitions/471.html",
    },
    {
        "id": "CWE_472",
        "code": "CWE-472",
        "url": "https://cwe.mitre.org/data/definitions/472.html",
    },
    {
        "id": "CWE_473",
        "code": "CWE-473",
        "url": "https://cwe.mitre.org/data/definitions/473.html",
    },
    {
        "id": "CWE_474",
        "code": "CWE-474",
        "url": "https://cwe.mitre.org/data/definitions/474.html",
    },
    {
        "id": "CWE_475",
        "code": "CWE-475",
        "url": "https://cwe.mitre.org/data/definitions/475.html",
    },
    {
        "id": "CWE_476",
        "code": "CWE-476",
        "url": "https://cwe.mitre.org/data/definitions/476.html",
    },
    {
        "id": "CWE_477",
        "code": "CWE-477",
        "url": "https://cwe.mitre.org/data/definitions/477.html",
    },
    {
        "id": "CWE_478",
        "code": "CWE-478",
        "url": "https://cwe.mitre.org/data/definitions/478.html",
    },
    {
        "id": "CWE_479",
        "code": "CWE-479",
        "url": "https://cwe.mitre.org/data/definitions/479.html",
    },
    {
        "id": "CWE_480",
        "code": "CWE-480",
        "url": "https://cwe.mitre.org/data/definitions/480.html",
    },
    {
        "id": "CWE_481",
        "code": "CWE-481",
        "url": "https://cwe.mitre.org/data/definitions/481.html",
    },
    {
        "id": "CWE_482",
        "code": "CWE-482",
        "url": "https://cwe.mitre.org/data/definitions/482.html",
    },
    {
        "id": "CWE_483",
        "code": "CWE-483",
        "url": "https://cwe.mitre.org/data/definitions/483.html",
    },
    {
        "id": "CWE_484",
        "code": "CWE-484",
        "url": "https://cwe.mitre.org/data/definitions/484.html",
    },
    {
        "id": "CWE_485",
        "code": "CWE-485",
        "url": "https://cwe.mitre.org/data/definitions/485.html",
    },
    {
        "id": "CWE_486",
        "code": "CWE-486",
        "url": "https://cwe.mitre.org/data/definitions/486.html",
    },
    {
        "id": "CWE_487",
        "code": "CWE-487",
        "url": "https://cwe.mitre.org/data/definitions/487.html",
    },
    {
        "id": "CWE_488",
        "code": "CWE-488",
        "url": "https://cwe.mitre.org/data/definitions/488.html",
    },
    {
        "id": "CWE_489",
        "code": "CWE-489",
        "url": "https://cwe.mitre.org/data/definitions/489.html",
    },
    {
        "id": "CWE_491",
        "code": "CWE-491",
        "url": "https://cwe.mitre.org/data/definitions/491.html",
    },
    {
        "id": "CWE_492",
        "code": "CWE-492",
        "url": "https://cwe.mitre.org/data/definitions/492.html",
    },
    {
        "id": "CWE_493",
        "code": "CWE-493",
        "url": "https://cwe.mitre.org/data/definitions/493.html",
    },
    {
        "id": "CWE_494",
        "code": "CWE-494",
        "url": "https://cwe.mitre.org/data/definitions/494.html",
    },
    {
        "id": "CWE_495",
        "code": "CWE-495",
        "url": "https://cwe.mitre.org/data/definitions/495.html",
    },
    {
        "id": "CWE_496",
        "code": "CWE-496",
        "url": "https://cwe.mitre.org/data/definitions/496.html",
    },
    {
        "id": "CWE_497",
        "code": "CWE-497",
        "url": "https://cwe.mitre.org/data/definitions/497.html",
    },
    {
        "id": "CWE_498",
        "code": "CWE-498",
        "url": "https://cwe.mitre.org/data/definitions/498.html",
    },
    {
        "id": "CWE_499",
        "code": "CWE-499",
        "url": "https://cwe.mitre.org/data/definitions/499.html",
    },
    {
        "id": "CWE_500",
        "code": "CWE-500",
        "url": "https://cwe.mitre.org/data/definitions/500.html",
    },
    {
        "id": "CWE_501",
        "code": "CWE-501",
        "url": "https://cwe.mitre.org/data/definitions/501.html",
    },
    {
        "id": "CWE_502",
        "code": "CWE-502",
        "url": "https://cwe.mitre.org/data/definitions/502.html",
    },
    {
        "id": "CWE_506",
        "code": "CWE-506",
        "url": "https://cwe.mitre.org/data/definitions/506.html",
    },
    {
        "id": "CWE_507",
        "code": "CWE-507",
        "url": "https://cwe.mitre.org/data/definitions/507.html",
    },
    {
        "id": "CWE_508",
        "code": "CWE-508",
        "url": "https://cwe.mitre.org/data/definitions/508.html",
    },
    {
        "id": "CWE_509",
        "code": "CWE-509",
        "url": "https://cwe.mitre.org/data/definitions/509.html",
    },
    {
        "id": "CWE_510",
        "code": "CWE-510",
        "url": "https://cwe.mitre.org/data/definitions/510.html",
    },
    {
        "id": "CWE_511",
        "code": "CWE-511",
        "url": "https://cwe.mitre.org/data/definitions/511.html",
    },
    {
        "id": "CWE_512",
        "code": "CWE-512",
        "url": "https://cwe.mitre.org/data/definitions/512.html",
    },
    {
        "id": "CWE_514",
        "code": "CWE-514",
        "url": "https://cwe.mitre.org/data/definitions/514.html",
    },
    {
        "id": "CWE_515",
        "code": "CWE-515",
        "url": "https://cwe.mitre.org/data/definitions/515.html",
    },
    {
        "id": "CWE_516",
        "code": "CWE-516",
        "url": "https://cwe.mitre.org/data/definitions/516.html",
    },
    {
        "id": "CWE_520",
        "code": "CWE-520",
        "url": "https://cwe.mitre.org/data/definitions/520.html",
    },
    {
        "id": "CWE_521",
        "code": "CWE-521",
        "url": "https://cwe.mitre.org/data/definitions/521.html",
    },
    {
        "id": "CWE_522",
        "code": "CWE-522",
        "url": "https://cwe.mitre.org/data/definitions/522.html",
    },
    {
        "id": "CWE_523",
        "code": "CWE-523",
        "url": "https://cwe.mitre.org/data/definitions/523.html",
    },
    {
        "id": "CWE_524",
        "code": "CWE-524",
        "url": "https://cwe.mitre.org/data/definitions/524.html",
    },
    {
        "id": "CWE_525",
        "code": "CWE-525",
        "url": "https://cwe.mitre.org/data/definitions/525.html",
    },
    {
        "id": "CWE_526",
        "code": "CWE-526",
        "url": "https://cwe.mitre.org/data/definitions/526.html",
    },
    {
        "id": "CWE_527",
        "code": "CWE-527",
        "url": "https://cwe.mitre.org/data/definitions/527.html",
    },
    {
        "id": "CWE_528",
        "code": "CWE-528",
        "url": "https://cwe.mitre.org/data/definitions/528.html",
    },
    {
        "id": "CWE_529",
        "code": "CWE-529",
        "url": "https://cwe.mitre.org/data/definitions/529.html",
    },
    {
        "id": "CWE_530",
        "code": "CWE-530",
        "url": "https://cwe.mitre.org/data/definitions/530.html",
    },
    {
        "id": "CWE_531",
        "code": "CWE-531",
        "url": "https://cwe.mitre.org/data/definitions/531.html",
    },
    {
        "id": "CWE_532",
        "code": "CWE-532",
        "url": "https://cwe.mitre.org/data/definitions/532.html",
    },
    {
        "id": "CWE_533",
        "code": "CWE-533",
        "url": "https://cwe.mitre.org/data/definitions/533.html",
    },
    {
        "id": "CWE_534",
        "code": "CWE-534",
        "url": "https://cwe.mitre.org/data/definitions/534.html",
    },
    {
        "id": "CWE_535",
        "code": "CWE-535",
        "url": "https://cwe.mitre.org/data/definitions/535.html",
    },
    {
        "id": "CWE_536",
        "code": "CWE-536",
        "url": "https://cwe.mitre.org/data/definitions/536.html",
    },
    {
        "id": "CWE_537",
        "code": "CWE-537",
        "url": "https://cwe.mitre.org/data/definitions/537.html",
    },
    {
        "id": "CWE_538",
        "code": "CWE-538",
        "url": "https://cwe.mitre.org/data/definitions/538.html",
    },
    {
        "id": "CWE_539",
        "code": "CWE-539",
        "url": "https://cwe.mitre.org/data/definitions/539.html",
    },
    {
        "id": "CWE_540",
        "code": "CWE-540",
        "url": "https://cwe.mitre.org/data/definitions/540.html",
    },
    {
        "id": "CWE_541",
        "code": "CWE-541",
        "url": "https://cwe.mitre.org/data/definitions/541.html",
    },
    {
        "id": "CWE_542",
        "code": "CWE-542",
        "url": "https://cwe.mitre.org/data/definitions/542.html",
    },
    {
        "id": "CWE_543",
        "code": "CWE-543",
        "url": "https://cwe.mitre.org/data/definitions/543.html",
    },
    {
        "id": "CWE_544",
        "code": "CWE-544",
        "url": "https://cwe.mitre.org/data/definitions/544.html",
    },
    {
        "id": "CWE_545",
        "code": "CWE-545",
        "url": "https://cwe.mitre.org/data/definitions/545.html",
    },
    {
        "id": "CWE_546",
        "code": "CWE-546",
        "url": "https://cwe.mitre.org/data/definitions/546.html",
    },
    {
        "id": "CWE_547",
        "code": "CWE-547",
        "url": "https://cwe.mitre.org/data/definitions/547.html",
    },
    {
        "id": "CWE_548",
        "code": "CWE-548",
        "url": "https://cwe.mitre.org/data/definitions/548.html",
    },
    {
        "id": "CWE_549",
        "code": "CWE-549",
        "url": "https://cwe.mitre.org/data/definitions/549.html",
    },
    {
        "id": "CWE_550",
        "code": "CWE-550",
        "url": "https://cwe.mitre.org/data/definitions/550.html",
    },
    {
        "id": "CWE_551",
        "code": "CWE-551",
        "url": "https://cwe.mitre.org/data/definitions/551.html",
    },
    {
        "id": "CWE_552",
        "code": "CWE-552",
        "url": "https://cwe.mitre.org/data/definitions/552.html",
    },
    {
        "id": "CWE_553",
        "code": "CWE-553",
        "url": "https://cwe.mitre.org/data/definitions/553.html",
    },
    {
        "id": "CWE_554",
        "code": "CWE-554",
        "url": "https://cwe.mitre.org/data/definitions/554.html",
    },
    {
        "id": "CWE_555",
        "code": "CWE-555",
        "url": "https://cwe.mitre.org/data/definitions/555.html",
    },
    {
        "id": "CWE_556",
        "code": "CWE-556",
        "url": "https://cwe.mitre.org/data/definitions/556.html",
    },
    {
        "id": "CWE_558",
        "code": "CWE-558",
        "url": "https://cwe.mitre.org/data/definitions/558.html",
    },
    {
        "id": "CWE_560",
        "code": "CWE-560",
        "url": "https://cwe.mitre.org/data/definitions/560.html",
    },
    {
        "id": "CWE_561",
        "code": "CWE-561",
        "url": "https://cwe.mitre.org/data/definitions/561.html",
    },
    {
        "id": "CWE_562",
        "code": "CWE-562",
        "url": "https://cwe.mitre.org/data/definitions/562.html",
    },
    {
        "id": "CWE_563",
        "code": "CWE-563",
        "url": "https://cwe.mitre.org/data/definitions/563.html",
    },
    {
        "id": "CWE_564",
        "code": "CWE-564",
        "url": "https://cwe.mitre.org/data/definitions/564.html",
    },
    {
        "id": "CWE_565",
        "code": "CWE-565",
        "url": "https://cwe.mitre.org/data/definitions/565.html",
    },
    {
        "id": "CWE_566",
        "code": "CWE-566",
        "url": "https://cwe.mitre.org/data/definitions/566.html",
    },
    {
        "id": "CWE_567",
        "code": "CWE-567",
        "url": "https://cwe.mitre.org/data/definitions/567.html",
    },
    {
        "id": "CWE_568",
        "code": "CWE-568",
        "url": "https://cwe.mitre.org/data/definitions/568.html",
    },
    {
        "id": "CWE_570",
        "code": "CWE-570",
        "url": "https://cwe.mitre.org/data/definitions/570.html",
    },
    {
        "id": "CWE_571",
        "code": "CWE-571",
        "url": "https://cwe.mitre.org/data/definitions/571.html",
    },
    {
        "id": "CWE_572",
        "code": "CWE-572",
        "url": "https://cwe.mitre.org/data/definitions/572.html",
    },
    {
        "id": "CWE_573",
        "code": "CWE-573",
        "url": "https://cwe.mitre.org/data/definitions/573.html",
    },
    {
        "id": "CWE_574",
        "code": "CWE-574",
        "url": "https://cwe.mitre.org/data/definitions/574.html",
    },
    {
        "id": "CWE_575",
        "code": "CWE-575",
        "url": "https://cwe.mitre.org/data/definitions/575.html",
    },
    {
        "id": "CWE_576",
        "code": "CWE-576",
        "url": "https://cwe.mitre.org/data/definitions/576.html",
    },
    {
        "id": "CWE_577",
        "code": "CWE-577",
        "url": "https://cwe.mitre.org/data/definitions/577.html",
    },
    {
        "id": "CWE_578",
        "code": "CWE-578",
        "url": "https://cwe.mitre.org/data/definitions/578.html",
    },
    {
        "id": "CWE_579",
        "code": "CWE-579",
        "url": "https://cwe.mitre.org/data/definitions/579.html",
    },
    {
        "id": "CWE_580",
        "code": "CWE-580",
        "url": "https://cwe.mitre.org/data/definitions/580.html",
    },
    {
        "id": "CWE_581",
        "code": "CWE-581",
        "url": "https://cwe.mitre.org/data/definitions/581.html",
    },
    {
        "id": "CWE_582",
        "code": "CWE-582",
        "url": "https://cwe.mitre.org/data/definitions/582.html",
    },
    {
        "id": "CWE_583",
        "code": "CWE-583",
        "url": "https://cwe.mitre.org/data/definitions/583.html",
    },
    {
        "id": "CWE_584",
        "code": "CWE-584",
        "url": "https://cwe.mitre.org/data/definitions/584.html",
    },
    {
        "id": "CWE_585",
        "code": "CWE-585",
        "url": "https://cwe.mitre.org/data/definitions/585.html",
    },
    {
        "id": "CWE_586",
        "code": "CWE-586",
        "url": "https://cwe.mitre.org/data/definitions/586.html",
    },
    {
        "id": "CWE_587",
        "code": "CWE-587",
        "url": "https://cwe.mitre.org/data/definitions/587.html",
    },
    {
        "id": "CWE_588",
        "code": "CWE-588",
        "url": "https://cwe.mitre.org/data/definitions/588.html",
    },
    {
        "id": "CWE_589",
        "code": "CWE-589",
        "url": "https://cwe.mitre.org/data/definitions/589.html",
    },
    {
        "id": "CWE_590",
        "code": "CWE-590",
        "url": "https://cwe.mitre.org/data/definitions/590.html",
    },
    {
        "id": "CWE_591",
        "code": "CWE-591",
        "url": "https://cwe.mitre.org/data/definitions/591.html",
    },
    {
        "id": "CWE_592",
        "code": "CWE-592",
        "url": "https://cwe.mitre.org/data/definitions/592.html",
    },
    {
        "id": "CWE_593",
        "code": "CWE-593",
        "url": "https://cwe.mitre.org/data/definitions/593.html",
    },
    {
        "id": "CWE_594",
        "code": "CWE-594",
        "url": "https://cwe.mitre.org/data/definitions/594.html",
    },
    {
        "id": "CWE_595",
        "code": "CWE-595",
        "url": "https://cwe.mitre.org/data/definitions/595.html",
    },
    {
        "id": "CWE_596",
        "code": "CWE-596",
        "url": "https://cwe.mitre.org/data/definitions/596.html",
    },
    {
        "id": "CWE_597",
        "code": "CWE-597",
        "url": "https://cwe.mitre.org/data/definitions/597.html",
    },
    {
        "id": "CWE_598",
        "code": "CWE-598",
        "url": "https://cwe.mitre.org/data/definitions/598.html",
    },
    {
        "id": "CWE_599",
        "code": "CWE-599",
        "url": "https://cwe.mitre.org/data/definitions/599.html",
    },
    {
        "id": "CWE_600",
        "code": "CWE-600",
        "url": "https://cwe.mitre.org/data/definitions/600.html",
    },
    {
        "id": "CWE_601",
        "code": "CWE-601",
        "url": "https://cwe.mitre.org/data/definitions/601.html",
    },
    {
        "id": "CWE_602",
        "code": "CWE-602",
        "url": "https://cwe.mitre.org/data/definitions/602.html",
    },
    {
        "id": "CWE_603",
        "code": "CWE-603",
        "url": "https://cwe.mitre.org/data/definitions/603.html",
    },
    {
        "id": "CWE_605",
        "code": "CWE-605",
        "url": "https://cwe.mitre.org/data/definitions/605.html",
    },
    {
        "id": "CWE_606",
        "code": "CWE-606",
        "url": "https://cwe.mitre.org/data/definitions/606.html",
    },
    {
        "id": "CWE_607",
        "code": "CWE-607",
        "url": "https://cwe.mitre.org/data/definitions/607.html",
    },
    {
        "id": "CWE_608",
        "code": "CWE-608",
        "url": "https://cwe.mitre.org/data/definitions/608.html",
    },
    {
        "id": "CWE_609",
        "code": "CWE-609",
        "url": "https://cwe.mitre.org/data/definitions/609.html",
    },
    {
        "id": "CWE_610",
        "code": "CWE-610",
        "url": "https://cwe.mitre.org/data/definitions/610.html",
    },
    {
        "id": "CWE_611",
        "code": "CWE-611",
        "url": "https://cwe.mitre.org/data/definitions/611.html",
    },
    {
        "id": "CWE_612",
        "code": "CWE-612",
        "url": "https://cwe.mitre.org/data/definitions/612.html",
    },
    {
        "id": "CWE_613",
        "code": "CWE-613",
        "url": "https://cwe.mitre.org/data/definitions/613.html",
    },
    {
        "id": "CWE_614",
        "code": "CWE-614",
        "url": "https://cwe.mitre.org/data/definitions/614.html",
    },
    {
        "id": "CWE_615",
        "code": "CWE-615",
        "url": "https://cwe.mitre.org/data/definitions/615.html",
    },
    {
        "id": "CWE_616",
        "code": "CWE-616",
        "url": "https://cwe.mitre.org/data/definitions/616.html",
    },
    {
        "id": "CWE_617",
        "code": "CWE-617",
        "url": "https://cwe.mitre.org/data/definitions/617.html",
    },
    {
        "id": "CWE_618",
        "code": "CWE-618",
        "url": "https://cwe.mitre.org/data/definitions/618.html",
    },
    {
        "id": "CWE_619",
        "code": "CWE-619",
        "url": "https://cwe.mitre.org/data/definitions/619.html",
    },
    {
        "id": "CWE_620",
        "code": "CWE-620",
        "url": "https://cwe.mitre.org/data/definitions/620.html",
    },
    {
        "id": "CWE_621",
        "code": "CWE-621",
        "url": "https://cwe.mitre.org/data/definitions/621.html",
    },
    {
        "id": "CWE_622",
        "code": "CWE-622",
        "url": "https://cwe.mitre.org/data/definitions/622.html",
    },
    {
        "id": "CWE_623",
        "code": "CWE-623",
        "url": "https://cwe.mitre.org/data/definitions/623.html",
    },
    {
        "id": "CWE_624",
        "code": "CWE-624",
        "url": "https://cwe.mitre.org/data/definitions/624.html",
    },
    {
        "id": "CWE_625",
        "code": "CWE-625",
        "url": "https://cwe.mitre.org/data/definitions/625.html",
    },
    {
        "id": "CWE_626",
        "code": "CWE-626",
        "url": "https://cwe.mitre.org/data/definitions/626.html",
    },
    {
        "id": "CWE_627",
        "code": "CWE-627",
        "url": "https://cwe.mitre.org/data/definitions/627.html",
    },
    {
        "id": "CWE_628",
        "code": "CWE-628",
        "url": "https://cwe.mitre.org/data/definitions/628.html",
    },
    {
        "id": "CWE_636",
        "code": "CWE-636",
        "url": "https://cwe.mitre.org/data/definitions/636.html",
    },
    {
        "id": "CWE_637",
        "code": "CWE-637",
        "url": "https://cwe.mitre.org/data/definitions/637.html",
    },
    {
        "id": "CWE_638",
        "code": "CWE-638",
        "url": "https://cwe.mitre.org/data/definitions/638.html",
    },
    {
        "id": "CWE_639",
        "code": "CWE-639",
        "url": "https://cwe.mitre.org/data/definitions/639.html",
    },
    {
        "id": "CWE_640",
        "code": "CWE-640",
        "url": "https://cwe.mitre.org/data/definitions/640.html",
    },
    {
        "id": "CWE_641",
        "code": "CWE-641",
        "url": "https://cwe.mitre.org/data/definitions/641.html",
    },
    {
        "id": "CWE_642",
        "code": "CWE-642",
        "url": "https://cwe.mitre.org/data/definitions/642.html",
    },
    {
        "id": "CWE_643",
        "code": "CWE-643",
        "url": "https://cwe.mitre.org/data/definitions/643.html",
    },
    {
        "id": "CWE_644",
        "code": "CWE-644",
        "url": "https://cwe.mitre.org/data/definitions/644.html",
    },
    {
        "id": "CWE_645",
        "code": "CWE-645",
        "url": "https://cwe.mitre.org/data/definitions/645.html",
    },
    {
        "id": "CWE_646",
        "code": "CWE-646",
        "url": "https://cwe.mitre.org/data/definitions/646.html",
    },
    {
        "id": "CWE_647",
        "code": "CWE-647",
        "url": "https://cwe.mitre.org/data/definitions/647.html",
    },
    {
        "id": "CWE_648",
        "code": "CWE-648",
        "url": "https://cwe.mitre.org/data/definitions/648.html",
    },
    {
        "id": "CWE_649",
        "code": "CWE-649",
        "url": "https://cwe.mitre.org/data/definitions/649.html",
    },
    {
        "id": "CWE_650",
        "code": "CWE-650",
        "url": "https://cwe.mitre.org/data/definitions/650.html",
    },
    {
        "id": "CWE_651",
        "code": "CWE-651",
        "url": "https://cwe.mitre.org/data/definitions/651.html",
    },
    {
        "id": "CWE_652",
        "code": "CWE-652",
        "url": "https://cwe.mitre.org/data/definitions/652.html",
    },
    {
        "id": "CWE_653",
        "code": "CWE-653",
        "url": "https://cwe.mitre.org/data/definitions/653.html",
    },
    {
        "id": "CWE_654",
        "code": "CWE-654",
        "url": "https://cwe.mitre.org/data/definitions/654.html",
    },
    {
        "id": "CWE_655",
        "code": "CWE-655",
        "url": "https://cwe.mitre.org/data/definitions/655.html",
    },
    {
        "id": "CWE_656",
        "code": "CWE-656",
        "url": "https://cwe.mitre.org/data/definitions/656.html",
    },
    {
        "id": "CWE_657",
        "code": "CWE-657",
        "url": "https://cwe.mitre.org/data/definitions/657.html",
    },
    {
        "id": "CWE_662",
        "code": "CWE-662",
        "url": "https://cwe.mitre.org/data/definitions/662.html",
    },
    {
        "id": "CWE_663",
        "code": "CWE-663",
        "url": "https://cwe.mitre.org/data/definitions/663.html",
    },
    {
        "id": "CWE_664",
        "code": "CWE-664",
        "url": "https://cwe.mitre.org/data/definitions/664.html",
    },
    {
        "id": "CWE_665",
        "code": "CWE-665",
        "url": "https://cwe.mitre.org/data/definitions/665.html",
    },
    {
        "id": "CWE_666",
        "code": "CWE-666",
        "url": "https://cwe.mitre.org/data/definitions/666.html",
    },
    {
        "id": "CWE_667",
        "code": "CWE-667",
        "url": "https://cwe.mitre.org/data/definitions/667.html",
    },
    {
        "id": "CWE_668",
        "code": "CWE-668",
        "url": "https://cwe.mitre.org/data/definitions/668.html",
    },
    {
        "id": "CWE_669",
        "code": "CWE-669",
        "url": "https://cwe.mitre.org/data/definitions/669.html",
    },
    {
        "id": "CWE_670",
        "code": "CWE-670",
        "url": "https://cwe.mitre.org/data/definitions/670.html",
    },
    {
        "id": "CWE_671",
        "code": "CWE-671",
        "url": "https://cwe.mitre.org/data/definitions/671.html",
    },
    {
        "id": "CWE_672",
        "code": "CWE-672",
        "url": "https://cwe.mitre.org/data/definitions/672.html",
    },
    {
        "id": "CWE_673",
        "code": "CWE-673",
        "url": "https://cwe.mitre.org/data/definitions/673.html",
    },
    {
        "id": "CWE_674",
        "code": "CWE-674",
        "url": "https://cwe.mitre.org/data/definitions/674.html",
    },
    {
        "id": "CWE_675",
        "code": "CWE-675",
        "url": "https://cwe.mitre.org/data/definitions/675.html",
    },
    {
        "id": "CWE_676",
        "code": "CWE-676",
        "url": "https://cwe.mitre.org/data/definitions/676.html",
    },
    {
        "id": "CWE_681",
        "code": "CWE-681",
        "url": "https://cwe.mitre.org/data/definitions/681.html",
    },
    {
        "id": "CWE_682",
        "code": "CWE-682",
        "url": "https://cwe.mitre.org/data/definitions/682.html",
    },
    {
        "id": "CWE_683",
        "code": "CWE-683",
        "url": "https://cwe.mitre.org/data/definitions/683.html",
    },
    {
        "id": "CWE_684",
        "code": "CWE-684",
        "url": "https://cwe.mitre.org/data/definitions/684.html",
    },
    {
        "id": "CWE_685",
        "code": "CWE-685",
        "url": "https://cwe.mitre.org/data/definitions/685.html",
    },
    {
        "id": "CWE_686",
        "code": "CWE-686",
        "url": "https://cwe.mitre.org/data/definitions/686.html",
    },
    {
        "id": "CWE_687",
        "code": "CWE-687",
        "url": "https://cwe.mitre.org/data/definitions/687.html",
    },
    {
        "id": "CWE_688",
        "code": "CWE-688",
        "url": "https://cwe.mitre.org/data/definitions/688.html",
    },
    {
        "id": "CWE_691",
        "code": "CWE-691",
        "url": "https://cwe.mitre.org/data/definitions/691.html",
    },
    {
        "id": "CWE_693",
        "code": "CWE-693",
        "url": "https://cwe.mitre.org/data/definitions/693.html",
    },
    {
        "id": "CWE_694",
        "code": "CWE-694",
        "url": "https://cwe.mitre.org/data/definitions/694.html",
    },
    {
        "id": "CWE_695",
        "code": "CWE-695",
        "url": "https://cwe.mitre.org/data/definitions/695.html",
    },
    {
        "id": "CWE_696",
        "code": "CWE-696",
        "url": "https://cwe.mitre.org/data/definitions/696.html",
    },
    {
        "id": "CWE_697",
        "code": "CWE-697",
        "url": "https://cwe.mitre.org/data/definitions/697.html",
    },
    {
        "id": "CWE_698",
        "code": "CWE-698",
        "url": "https://cwe.mitre.org/data/definitions/698.html",
    },
    {
        "id": "CWE_703",
        "code": "CWE-703",
        "url": "https://cwe.mitre.org/data/definitions/703.html",
    },
    {
        "id": "CWE_704",
        "code": "CWE-704",
        "url": "https://cwe.mitre.org/data/definitions/704.html",
    },
    {
        "id": "CWE_705",
        "code": "CWE-705",
        "url": "https://cwe.mitre.org/data/definitions/705.html",
    },
    {
        "id": "CWE_706",
        "code": "CWE-706",
        "url": "https://cwe.mitre.org/data/definitions/706.html",
    },
    {
        "id": "CWE_707",
        "code": "CWE-707",
        "url": "https://cwe.mitre.org/data/definitions/707.html",
    },
    {
        "id": "CWE_708",
        "code": "CWE-708",
        "url": "https://cwe.mitre.org/data/definitions/708.html",
    },
    {
        "id": "CWE_710",
        "code": "CWE-710",
        "url": "https://cwe.mitre.org/data/definitions/710.html",
    },
    {
        "id": "CWE_732",
        "code": "CWE-732",
        "url": "https://cwe.mitre.org/data/definitions/732.html",
    },
    {
        "id": "CWE_733",
        "code": "CWE-733",
        "url": "https://cwe.mitre.org/data/definitions/733.html",
    },
    {
        "id": "CWE_749",
        "code": "CWE-749",
        "url": "https://cwe.mitre.org/data/definitions/749.html",
    },
    {
        "id": "CWE_754",
        "code": "CWE-754",
        "url": "https://cwe.mitre.org/data/definitions/754.html",
    },
    {
        "id": "CWE_755",
        "code": "CWE-755",
        "url": "https://cwe.mitre.org/data/definitions/755.html",
    },
    {
        "id": "CWE_756",
        "code": "CWE-756",
        "url": "https://cwe.mitre.org/data/definitions/756.html",
    },
    {
        "id": "CWE_757",
        "code": "CWE-757",
        "url": "https://cwe.mitre.org/data/definitions/757.html",
    },
    {
        "id": "CWE_758",
        "code": "CWE-758",
        "url": "https://cwe.mitre.org/data/definitions/758.html",
    },
    {
        "id": "CWE_759",
        "code": "CWE-759",
        "url": "https://cwe.mitre.org/data/definitions/759.html",
    },
    {
        "id": "CWE_760",
        "code": "CWE-760",
        "url": "https://cwe.mitre.org/data/definitions/760.html",
    },
    {
        "id": "CWE_761",
        "code": "CWE-761",
        "url": "https://cwe.mitre.org/data/definitions/761.html",
    },
    {
        "id": "CWE_762",
        "code": "CWE-762",
        "url": "https://cwe.mitre.org/data/definitions/762.html",
    },
    {
        "id": "CWE_763",
        "code": "CWE-763",
        "url": "https://cwe.mitre.org/data/definitions/763.html",
    },
    {
        "id": "CWE_764",
        "code": "CWE-764",
        "url": "https://cwe.mitre.org/data/definitions/764.html",
    },
    {
        "id": "CWE_765",
        "code": "CWE-765",
        "url": "https://cwe.mitre.org/data/definitions/765.html",
    },
    {
        "id": "CWE_766",
        "code": "CWE-766",
        "url": "https://cwe.mitre.org/data/definitions/766.html",
    },
    {
        "id": "CWE_767",
        "code": "CWE-767",
        "url": "https://cwe.mitre.org/data/definitions/767.html",
    },
    {
        "id": "CWE_768",
        "code": "CWE-768",
        "url": "https://cwe.mitre.org/data/definitions/768.html",
    },
    {
        "id": "CWE_770",
        "code": "CWE-770",
        "url": "https://cwe.mitre.org/data/definitions/770.html",
    },
    {
        "id": "CWE_771",
        "code": "CWE-771",
        "url": "https://cwe.mitre.org/data/definitions/771.html",
    },
    {
        "id": "CWE_772",
        "code": "CWE-772",
        "url": "https://cwe.mitre.org/data/definitions/772.html",
    },
    {
        "id": "CWE_773",
        "code": "CWE-773",
        "url": "https://cwe.mitre.org/data/definitions/773.html",
    },
    {
        "id": "CWE_774",
        "code": "CWE-774",
        "url": "https://cwe.mitre.org/data/definitions/774.html",
    },
    {
        "id": "CWE_775",
        "code": "CWE-775",
        "url": "https://cwe.mitre.org/data/definitions/775.html",
    },
    {
        "id": "CWE_776",
        "code": "CWE-776",
        "url": "https://cwe.mitre.org/data/definitions/776.html",
    },
    {
        "id": "CWE_777",
        "code": "CWE-777",
        "url": "https://cwe.mitre.org/data/definitions/777.html",
    },
    {
        "id": "CWE_778",
        "code": "CWE-778",
        "url": "https://cwe.mitre.org/data/definitions/778.html",
    },
    {
        "id": "CWE_779",
        "code": "CWE-779",
        "url": "https://cwe.mitre.org/data/definitions/779.html",
    },
    {
        "id": "CWE_780",
        "code": "CWE-780",
        "url": "https://cwe.mitre.org/data/definitions/780.html",
    },
    {
        "id": "CWE_781",
        "code": "CWE-781",
        "url": "https://cwe.mitre.org/data/definitions/781.html",
    },
    {
        "id": "CWE_782",
        "code": "CWE-782",
        "url": "https://cwe.mitre.org/data/definitions/782.html",
    },
    {
        "id": "CWE_783",
        "code": "CWE-783",
        "url": "https://cwe.mitre.org/data/definitions/783.html",
    },
    {
        "id": "CWE_784",
        "code": "CWE-784",
        "url": "https://cwe.mitre.org/data/definitions/784.html",
    },
    {
        "id": "CWE_785",
        "code": "CWE-785",
        "url": "https://cwe.mitre.org/data/definitions/785.html",
    },
    {
        "id": "CWE_786",
        "code": "CWE-786",
        "url": "https://cwe.mitre.org/data/definitions/786.html",
    },
    {
        "id": "CWE_787",
        "code": "CWE-787",
        "url": "https://cwe.mitre.org/data/definitions/787.html",
    },
    {
        "id": "CWE_788",
        "code": "CWE-788",
        "url": "https://cwe.mitre.org/data/definitions/788.html",
    },
    {
        "id": "CWE_789",
        "code": "CWE-789",
        "url": "https://cwe.mitre.org/data/definitions/789.html",
    },
    {
        "id": "CWE_790",
        "code": "CWE-790",
        "url": "https://cwe.mitre.org/data/definitions/790.html",
    },
    {
        "id": "CWE_791",
        "code": "CWE-791",
        "url": "https://cwe.mitre.org/data/definitions/791.html",
    },
    {
        "id": "CWE_792",
        "code": "CWE-792",
        "url": "https://cwe.mitre.org/data/definitions/792.html",
    },
    {
        "id": "CWE_793",
        "code": "CWE-793",
        "url": "https://cwe.mitre.org/data/definitions/793.html",
    },
    {
        "id": "CWE_794",
        "code": "CWE-794",
        "url": "https://cwe.mitre.org/data/definitions/794.html",
    },
    {
        "id": "CWE_795",
        "code": "CWE-795",
        "url": "https://cwe.mitre.org/data/definitions/795.html",
    },
    {
        "id": "CWE_796",
        "code": "CWE-796",
        "url": "https://cwe.mitre.org/data/definitions/796.html",
    },
    {
        "id": "CWE_797",
        "code": "CWE-797",
        "url": "https://cwe.mitre.org/data/definitions/797.html",
    },
    {
        "id": "CWE_798",
        "code": "CWE-798",
        "url": "https://cwe.mitre.org/data/definitions/798.html",
    },
    {
        "id": "CWE_799",
        "code": "CWE-799",
        "url": "https://cwe.mitre.org/data/definitions/799.html",
    },
    {
        "id": "CWE_804",
        "code": "CWE-804",
        "url": "https://cwe.mitre.org/data/definitions/804.html",
    },
    {
        "id": "CWE_805",
        "code": "CWE-805",
        "url": "https://cwe.mitre.org/data/definitions/805.html",
    },
    {
        "id": "CWE_806",
        "code": "CWE-806",
        "url": "https://cwe.mitre.org/data/definitions/806.html",
    },
    {
        "id": "CWE_807",
        "code": "CWE-807",
        "url": "https://cwe.mitre.org/data/definitions/807.html",
    },
    {
        "id": "CWE_840",
        "code": "CWE-840",
        "url": "https://cwe.mitre.org/data/definitions/840.html",
    },
    {
        "id": "CWE_862",
        "code": "CWE-862",
        "url": "https://cwe.mitre.org/data/definitions/862.html",
    },
    {
        "id": "CWE_863",
        "code": "CWE-863",
        "url": "https://cwe.mitre.org/data/definitions/863.html",
    },
    {
        "id": "CWE_916",
        "code": "CWE-916",
        "url": "https://cwe.mitre.org/data/definitions/916.html",
    },
    {
        "id": "CWE_922",
        "code": "CWE-922",
        "url": "https://cwe.mitre.org/data/definitions/922.html",
    },
    {
        "id": "CWE_925",
        "code": "CWE-925",
        "url": "https://cwe.mitre.org/data/definitions/925.html",
    },
    {
        "id": "CWE_926",
        "code": "CWE-926",
        "url": "https://cwe.mitre.org/data/definitions/926.html",
    },
    {
        "id": "CWE_942",
        "code": "CWE-942",
        "url": "https://cwe.mitre.org/data/definitions/942.html",
    },
    {
        "id": "CWE_1004",
        "code": "CWE-1004",
        "url": "https://cwe.mitre.org/data/definitions/1004.html",
    },
    {
        "id": "CWE_1021",
        "code": "CWE-1021",
        "url": "https://cwe.mitre.org/data/definitions/1021.html",
    },
    {
        "id": "CWE_1299",
        "code": "CWE-1299",
        "url": "https://cwe.mitre.org/data/definitions/1299.html",
    },
]


class CWE:
    def __init__(self, id, code, url):
        self.pk = id
        self.id = id
        self.url = url
        self.code = code

    def __str__(self):
        return f"{self.id} - {self.code} - {self.url}"

    def __repr__(self):
        return "<CWE: %s>" % self.__str__()


CWE_DATA = {d["id"]: CWE(**d) for d in data}
